==> dde-shell_1.99.6.tar.xz: BUILD/panels/dock/dcc-dock-plugin/translations/dock_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>PluginArea</name>
    <message>
        <source>Plugin Area</source>
        <translation>Strefa wtyczek</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Wybierz, które wtyczki pojawią się w doku</translation>
    </message>
</context>
<context>
    <name>dock</name>
    <message>
        <source>Desktop and taskbar</source>
        <translation>Pulpit i pasek zadań</translation>
    </message>
    <message>
        <source>Set the display and size of icons on the desktop</source>
        <translation>Ustaw ekran i rozmiar ikon na pulpicie</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dock</source>
        <translation>Dok</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <source>Fashion</source>
        <translation>Modny</translation>
    </message>
    <message>
        <source>Efficient-left</source>
        <translation>Wydajny-lewo</translation>
    </message>
    <message>
        <source>Efficient-center</source>
        <translation>Wydajny-środek</translation>
    </message>
    <message>
        <source>Dock size</source>
        <translation>Rozmiar doku</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Mały</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Duży</translation>
    </message>
    <message>
        <source>Position on the screen</source>
        <translation>Pozycja na ekranie</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Lewo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Prawo</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Zawsze wyświetlaj</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Zawsze ukrywaj</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Inteligentne ukrywanie</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Wiele ekranów</translation>
    </message>
    <message>
        <source>Set the position of the taskbar on the screen</source>
        <translation>Ustaw położenie paska zadań na ekranie</translation>
    </message>
    <message>
        <source>Only on main</source>
        <translation>Tylko na głównym</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Na ekranie, tam gdzie jest kursor</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Strefa wtyczek</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Wybierz, które ikony pojawią się w doku</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.7.tar.xz: BUILD/panels/dock/dcc-dock-plugin/translations/dock_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>PluginArea</name>
    <message>
        <source>Plugin Area</source>
        <translation>Strefa wtyczek</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Wybierz, które wtyczki pojawią się w doku</translation>
    </message>
</context>
<context>
    <name>dock</name>
    <message>
        <source>Desktop and taskbar</source>
        <translation>Pulpit i pasek zadań</translation>
    </message>
    <message>
        <source>Set the display and size of icons on the desktop</source>
        <translation>Ustaw ekran i rozmiar ikon na pulpicie</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dock</source>
        <translation>Dok</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <source>Dock size</source>
        <translation>Rozmiar doku</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Mały</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Duży</translation>
    </message>
    <message>
        <source>Position on the screen</source>
        <translation>Pozycja na ekranie</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Lewo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Prawo</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Zawsze wyświetlaj</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Zawsze ukrywaj</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Inteligentne ukrywanie</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Wiele ekranów</translation>
    </message>
    <message>
        <source>Set the position of the taskbar on the screen</source>
        <translation>Ustaw położenie paska zadań na ekranie</translation>
    </message>
    <message>
        <source>Only on main</source>
        <translation>Tylko na głównym</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Na ekranie, tam gdzie jest kursor</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Strefa wtyczek</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Wybierz, które ikony pojawią się w doku</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
